@@ -1,12 +1,14 @@
 # This file is encoded in ShiftJIS.
 die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";
 
+use Sjis;
+
 # G[ɂ͂ȂȂǕiRj
 print "ۏ\net";
 
 __END__
 
-esjis.pl ̏ʂȉɂȂ邱Ƃ҂Ă
+Sjis.pm ̏ʂȉɂȂ邱Ƃ҂Ă
 
 print "ۏ\\net";
 
